==> llm-docs-0.1.4.tgz: package/docs/api/reference.md <==
---
id: api-reference
---
# API Reference Guide

<!-- title: API Reference Guide -->
<!-- description: Comprehensive API reference for the LLM Platform Platform -->
<!-- lastUpdated: 2024-03-19 -->

## Overview

This guide provides a comprehensive reference for all APIs in the LLM Platform Platform. It includes detailed documentation for REST and GraphQL endpoints, authentication, error handling, and best practices.

## Authentication

### Bearer Token

```http
Authorization: Bearer <token>
```

### API Key

```http
X-API-Key: <key>
```

## REST API

### Base URL

```
https://api.bluefly.io/v1
```

### Endpoints

#### Agents

```http
GET /agents
GET /agents/{id}
POST /agents
PUT /agents/{id}
DELETE /agents/{id}
```

#### Models

```http
GET /models
GET /models/{id}
POST /models
PUT /models/{id}
DELETE /models/{id}
```

#### Memory

```http
GET /memory
GET /memory/{id}
POST /memory
PUT /memory/{id}
DELETE /memory/{id}
```

### Request/Response Examples

#### List Agents

```http
GET /agents
Authorization: Bearer <token>

{
  "data": [
    {
      "id": "agent-1",
      "name": "Assistant",
      "provider": "native-ai",
      "model": "claude-3-opus"
    }
  ],
  "meta": {
    "total": 1,
    "page": 1,
    "per_page": 10
  }
}
```

#### Create Agent

```http
POST /agents
Authorization: Bearer <token>
Content-Type: application/json

{
  "name": "Assistant",
  "provider": "native-ai",
  "model": "claude-3-opus",
  "config": {
    "temperature": 0.7,
    "max_tokens": 1000
  }
}

{
  "data": {
    "id": "agent-2",
    "name": "Assistant",
    "provider": "native-ai",
    "model": "claude-3-opus",
    "config": {
      "temperature": 0.7,
      "max_tokens": 1000
    }
  }
}
```

## GraphQL API

### Endpoint

```
https://api.bluefly.io/graphql
```

### Schema

```graphql
type Agent {
  id: ID!
  name: String!
  provider: String!
  model: String!
  config: AgentConfig
}

type AgentConfig {
  temperature: Float
  maxTokens: Int
}

type Query {
  agents: [Agent!]!
  agent(id: ID!): Agent
  models: [Model!]!
  model(id: ID!): Model
}

type Mutation {
  createAgent(input: CreateAgentInput!): Agent!
  updateAgent(id: ID!, input: UpdateAgentInput!): Agent!
  deleteAgent(id: ID!): Boolean!
}
```

### Queries

#### List Agents

```graphql
query {
  agents {
    id
    name
    provider
    model
    config {
      temperature
      maxTokens
    }
  }
}
```

#### Get Agent

```graphql
query {
  agent(id: "agent-1") {
    id
    name
    provider
    model
    config {
      temperature
      maxTokens
    }
  }
}
```

### Mutations

#### Create Agent

```graphql
mutation {
  createAgent(input: {
    name: "Assistant"
    provider: "native-ai"
    model: "claude-3-opus"
    config: {
      temperature: 0.7
      maxTokens: 1000
    }
  }) {
    id
    name
    provider
    model
    config {
      temperature
      maxTokens
    }
  }
}
```

## Error Handling

### Error Response

```json
{
  "error": {
    "code": "validation_error",
    "message": "Invalid input",
    "details": {
      "name": ["Required field"],
      "provider": ["Invalid provider"]
    }
  }
}
```

### Error Codes

| Code | Description |
|------|-------------|
| `validation_error` | Input validation failed |
| `authentication_error` | Authentication failed |
| `authorization_error` | Authorization failed |
| `not_found` | Resource not found |
| `rate_limit_exceeded` | Rate limit exceeded |
| `internal_error` | Internal server error |

## Rate Limiting

### Limits

- 100 requests per minute per API key
- 1000 requests per hour per API key
- 10000 requests per day per API key

### Headers

```http
X-RateLimit-Limit: 100
X-RateLimit-Remaining: 99
X-RateLimit-Reset: 1616123456
```

## Versioning

### URL Versioning

```
https://api.bluefly.io/v1/agents
https://api.bluefly.io/v2/agents
```

### Header Versioning

```http
Accept: application/vnd.bluefly.v1+json
```

## SDKs

### TypeScript/JavaScript

```typescript
import { LLM PlatformClient } from '@bluefly/api-client';

const client = new LLM PlatformClient({
  apiKey: 'your-api-key'
});

const agents = await client.agents.list();
const agent = await client.agents.create({
  name: 'Assistant',
  provider: 'native-ai',
  model: 'claude-3-opus'
});
```

### PHP

```php
use LLM Platform\Client;

$client = new Client([
    'api_key' => 'your-api-key'
]);

$agents = $client->agents->list();
$agent = $client->agents->create([
    'name' => 'Assistant',
    'provider' => 'native-ai',
    'model' => 'claude-3-opus'
]);
```

## Best Practices

1. **Authentication**
   - Use bearer tokens
   - Rotate API keys
   - Secure credentials
   - Use HTTPS

2. **Requests**
   - Use proper methods
   - Include headers
   - Validate input
   - Handle errors

3. **Responses**
   - Check status codes
   - Parse errors
   - Handle rate limits
   - Cache responses

4. **Development**
   - Use SDKs
   - Follow patterns
   - Test endpoints
   - Monitor usage

## Related Documentation

- [OpenAPI Validation](openapi-validation)
- [API Normalization](normalization)
- [REST API](rest)
- [GraphQL API](graphql)
- [Security Guide](../operations/security)
- [Development Guide](../development/README)

==> llm-docs-1.0.1.tgz: package/docs/api/reference.md <==
---
id: api-reference
---
# API Reference Guide

<!-- title: API Reference Guide -->
<!-- description: Comprehensive API reference for the Bluefly Platform -->
<!-- lastUpdated: 2024-03-19 -->

## Overview

This guide provides a comprehensive reference for all APIs in the Bluefly Platform. It includes detailed documentation for REST and GraphQL endpoints, authentication, error handling, and best practices.

## Authentication

### Bearer Token

```http
Authorization: Bearer <token>
```

### API Key

```http
X-API-Key: <key>
```

## REST API

### Base URL

```
https://api.bluefly.io/v1
```

### Endpoints

#### Agents

```http
GET /agents
GET /agents/{id}
POST /agents
PUT /agents/{id}
DELETE /agents/{id}
```

#### Models

```http
GET /models
GET /models/{id}
POST /models
PUT /models/{id}
DELETE /models/{id}
```

#### Memory

```http
GET /memory
GET /memory/{id}
POST /memory
PUT /memory/{id}
DELETE /memory/{id}
```

### Request/Response Examples

#### List Agents

```http
GET /agents
Authorization: Bearer <token>

{
  "data": [
    {
      "id": "agent-1",
      "name": "Assistant",
      "provider": "native-ai",
      "model": "claude-3-opus"
    }
  ],
  "meta": {
    "total": 1,
    "page": 1,
    "per_page": 10
  }
}
```

#### Create Agent

```http
POST /agents
Authorization: Bearer <token>
Content-Type: application/json

{
  "name": "Assistant",
  "provider": "native-ai",
  "model": "claude-3-opus",
  "config": {
    "temperature": 0.7,
    "max_tokens": 1000
  }
}

{
  "data": {
    "id": "agent-2",
    "name": "Assistant",
    "provider": "native-ai",
    "model": "claude-3-opus",
    "config": {
      "temperature": 0.7,
      "max_tokens": 1000
    }
  }
}
```

## GraphQL API

### Endpoint

```
https://api.bluefly.io/graphql
```

### Schema

```graphql
type Agent {
  id: ID!
  name: String!
  provider: String!
  model: String!
  config: AgentConfig
}

type AgentConfig {
  temperature: Float
  maxTokens: Int
}

type Query {
  agents: [Agent!]!
  agent(id: ID!): Agent
  models: [Model!]!
  model(id: ID!): Model
}

type Mutation {
  createAgent(input: CreateAgentInput!): Agent!
  updateAgent(id: ID!, input: UpdateAgentInput!): Agent!
  deleteAgent(id: ID!): Boolean!
}
```

### Queries

#### List Agents

```graphql
query {
  agents {
    id
    name
    provider
    model
    config {
      temperature
      maxTokens
    }
  }
}
```

#### Get Agent

```graphql
query {
  agent(id: "agent-1") {
    id
    name
    provider
    model
    config {
      temperature
      maxTokens
    }
  }
}
```

### Mutations

#### Create Agent

```graphql
mutation {
  createAgent(input: {
    name: "Assistant"
    provider: "native-ai"
    model: "claude-3-opus"
    config: {
      temperature: 0.7
      maxTokens: 1000
    }
  }) {
    id
    name
    provider
    model
    config {
      temperature
      maxTokens
    }
  }
}
```

## Error Handling

### Error Response

```json
{
  "error": {
    "code": "validation_error",
    "message": "Invalid input",
    "details": {
      "name": ["Required field"],
      "provider": ["Invalid provider"]
    }
  }
}
```

### Error Codes

| Code | Description |
|------|-------------|
| `validation_error` | Input validation failed |
| `authentication_error` | Authentication failed |
| `authorization_error` | Authorization failed |
| `not_found` | Resource not found |
| `rate_limit_exceeded` | Rate limit exceeded |
| `internal_error` | Internal server error |

## Rate Limiting

### Limits

- 100 requests per minute per API key
- 1000 requests per hour per API key
- 10000 requests per day per API key

### Headers

```http
X-RateLimit-Limit: 100
X-RateLimit-Remaining: 99
X-RateLimit-Reset: 1616123456
```

## Versioning

### URL Versioning

```
https://api.bluefly.io/v1/agents
https://api.bluefly.io/v2/agents
```

### Header Versioning

```http
Accept: application/vnd.bluefly.v1+json
```

## SDKs

### TypeScript/JavaScript

```typescript
import { BlueflyClient } from '@bluefly/api-client';

const client = new BlueflyClient({
  apiKey: 'your-api-key'
});

const agents = await client.agents.list();
const agent = await client.agents.create({
  name: 'Assistant',
  provider: 'native-ai',
  model: 'claude-3-opus'
});
```

### PHP

```php
use Bluefly\Client;

$client = new Client([
    'api_key' => 'your-api-key'
]);

$agents = $client->agents->list();
$agent = $client->agents->create([
    'name' => 'Assistant',
    'provider' => 'native-ai',
    'model' => 'claude-3-opus'
]);
```

## Best Practices

1. **Authentication**
   - Use bearer tokens
   - Rotate API keys
   - Secure credentials
   - Use HTTPS

2. **Requests**
   - Use proper methods
   - Include headers
   - Validate input
   - Handle errors

3. **Responses**
   - Check status codes
   - Parse errors
   - Handle rate limits
   - Cache responses

4. **Development**
   - Use SDKs
   - Follow patterns
   - Test endpoints
   - Monitor usage

## Related Documentation

- [OpenAPI Validation](openapi-validation)
- [API Normalization](normalization)
- [REST API](rest)
- [GraphQL API](graphql)
- [Security Guide](../operations/security)
- [Development Guide](../development/README)
